"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WorkflowBuilder = void 0;
class WorkflowBuilder {
    constructor() {
        this.workflow = {
            jobs: {},
        };
    }
    setName(name) {
        this.workflow.name = name;
        return this;
    }
    setRunName(runName) {
        this.workflow["run-name"] = runName;
        return this;
    }
    setPermissions(permissions) {
        this.workflow.permissions = permissions;
        return this;
    }
    addEnv(key, value) {
        if (!this.workflow.env) {
            this.workflow.env = {};
        }
        this.workflow.env[key] = value;
        return this;
    }
    addOn(on) {
        this.workflow.on = on;
        return this;
    }
    addJob(name, job) {
        this.workflow.jobs[name] = job;
        return this;
    }
    build() {
        if (!this.workflow.on)
            throw new Error('"On" describes events for Github actions and must be set.');
        if (Object.values(this.workflow.jobs).length === 0)
            throw new Error('At least one job is required.');
        return this.workflow;
    }
}
exports.WorkflowBuilder = WorkflowBuilder;
